# Security Policy

## Supported Versions

<!--
Use this section to tell people about which versions of your project are
currently being supported with security updates.
-->

| Version | Supported          |
| ------- | ------------------ |
|   0.x   | :white_check_mark: |

## Reporting a PUBLIC Vulnerability

Please report any vulnerabilities that can be publicly shared via [GitHub Issues](https://github.com/mlcommons/GaNDLF/issues/new/choose).

## Reporting a PRIVATE Vulnerability

Please report any vulnerabilities that cannot be publicly shared via [email](mailto:gandlf@mlcommons.org).
